@@ -9,6 +9,7 @@ load_dotenv(find_dotenv())
 aws_region = os.environ.get('AWS_DEFAULT_REGION', 'us-east-1')
 aws_access_key = os.environ.get('AWS_ACCESS_KEY_ID')
 aws_secret_key = os.environ.get('AWS_SECRET_ACCESS_KEY')
+aws_s3_provider = os.environ.get('AWS_S3_PROVIDER') or 's3'
 aws_s3_bucket = os.environ.get('AWS_S3_BUCKET')
 onesignal_app_id = os.environ.get('ONESIGNAL_APP_ID')
 onesignal_api_key = os.environ.get('ONESIGNAL_API_KEY')
@@ -24,7 +25,7 @@ class SignaTestCase(unittest.TestCase):
     def test_new_s3(self):
         key = 'test.txt'
         _ = signa.new(
-            's3',
+            aws_s3_provider,
             method='PUT',
             region=aws_region,
             bucket=aws_s3_bucket,
